#import "@preview/cetz:0.2.2"

// Calculating and plotting wavelengths of the Lyman series
#let ns = (2, 3, 4, 5, 6, 1e12)
#let display(n) = if n == 1e12 { $infinity$ } else { str(n) }

// Using the Rydberg formula
#let wavelengths = ns.map(n => 1e9 / (1.097e7 * (1 - 1 / (n * n))))

#align(center)[
  #table(
    columns: (1fr,) * 6, align: center,
    // header row
    table.cell(colspan: 6)[Lyman Series Transition Wavelengths (nm)],
    // second row
    ..ns.map(n => [ n = #display(n) ]),
    // third row
    ..wavelengths.map(l => [ #calc.round(l, digits: 2) ])
  )

  #cetz.canvas({
    import cetz.draw: content
    import cetz.plot: *

    let opts = (
      size: (16, 3),
      axis-style: "scientific",
      x-label: $lambda "(nm)"$, y-label: none,
      x-tick-step: 2, y-tick-step: none,
      x-min: 86, x-max: 126,
    )
      
    plot(..opts, name: "plot", {
      for (l, n) in wavelengths.zip(ns) {
        // draw a vertical line
        add-vline(l, min: 0, max: 1, style: (stroke: black))
        // add anchors to "locate" the top of each vertical line
        add-anchor(str(n), (l, 1)) 
      }
    })
    for (l, n) in wavelengths.zip(ns) {
      // draw in the text labels at the anchors specified above
      content(
        "plot." + str(n),
        [n = #display(n)],
        anchor: "south-west",
        padding: 2pt,
        angle: 30deg
      )
    }
  })
]
